@@ -4,7 +4,7 @@ import numpy as np
 
 def power_spectral_density(array, signal_frequency, window_size):
     """
-    Calculate the power spectral density on EEG signal, and then extract the band power of Delta, Theta, Alpha, Beta, and Gamma band.
+    Calculate the power spectral density of given signal.
     We support both 1d array input and DEEG standard input (p,m,e). For the later format, we calculate PSD on dim "e" and return a (p,m) numpy array.
 
     input:
@@ -12,21 +12,15 @@ def power_spectral_density(array, signal_frequency, window_size):
         signal_frequency: int. Original frequency of the signal
         window_size: int. Size of the window
     return
-        band power: tuple or numpy array, depends on the input shape
+        PSD: tuple or numpy array, depends on the input shape
     """
     def cal_psd(s, sf, ws):
-        freqs, psd = scipy.signal.welch(s, sf, nperseg=ws)
-        freq_res = freqs[1] - freqs[0]
-        delta = scipy.integrate.simps(psd[np.logical_and(freqs >= 0, freqs < 4)], dx=freq_res)
-        theta = scipy.integrate.simps(psd[np.logical_and(freqs >= 4, freqs <= 7)], dx=freq_res)
-        alpha = scipy.integrate.simps(psd[np.logical_and(freqs >= 8, freqs <= 15)], dx=freq_res)
-        beta = scipy.integrate.simps(psd[np.logical_and(freqs >= 16, freqs <= 31)], dx=freq_res)
-        gamma = scipy.integrate.simps(psd[np.logical_and(freqs >= 32, freqs <= freqs[-1])], dx=freq_res)
-        return delta, theta, alpha, beta, gamma
+        freqs, psd= scipy.signal.welch(s, fs=sf, window='hanning', nperseg=ws, noverlap=None, nfft=None, detrend='constant', return_onesided=True, scaling='density', axis=-1)
+        return psd
     if len(array.shape) == 1:
         return cal_psd(array, signal_frequency, window_size)
     else:
-        return np.apply_along_axis(cal_psd, axis=-1, arr=array, sf=signal_frequency, ws=window_size)
+        return np.apply_along_axis(cal_psd, axis = -1, arr = array, sf = signal_frequency, ws = window_size)
 
 
 def mean_absolute_deviation(array):
@@ -385,3 +379,42 @@ def differential_caudality(array, channel_name):
     else:
         return np.apply_along_axis(cal_dcau, axis=-1, arr=DE, cn=channel_name)
 
+
+def cal_eeg_features(array, sf, ws, channel_name=None):
+    """
+    Calculate all EEG features. If "channel_name" is not None, also include multi-channel features
+    input:
+        array: numpy array. The temporal signal for feature extraction. 1d or with multiple dimensions
+        sf: int or float. Signal frequency for PSD calculation.
+        wz: int or float. Window size for PSD calculation.
+        channel_name: list or 1d array. The names of all the channels of the EEG signal.
+    return
+        feature_array: numpy array. Calculated features with the same shape as input array.
+        feature_list: list of str. The order of EEG features, corresponding to "feature array".
+    """
+    feature_list = ["PSD", "mean_absolute_difference", "skewness", "kurtosis", "DE"]
+    if len(array.shape)<2:
+        # If input is a single signal, multi-channel features are excluded
+        psd = power_spectral_density(array, sf, ws)
+        mad = mean_absolute_deviation(array)
+        skw = skewness(array)
+        krt = kurtosis(array)
+        de = differential_entropy(array)
+        return np.append(psd, [mad,skw,krt,de]), feature_list
+    else:
+        # add new axis for numeric features to concatenate with vectorized feature
+        psd = power_spectral_density(array, sf, ws)
+        mad = mean_absolute_deviation(array)[..., np.newaxis]
+        skw = skewness(array)[..., np.newaxis]
+        krt = kurtosis(array)[..., np.newaxis]
+        de = differential_entropy(array)[..., np.newaxis]
+        if channel_name is not None:
+            feature_list.append(["RASM", "DASM", "DCAU"])
+            rasm = rational_asymmetry(array, channel_name)
+            dasm = differential_asymmetry(array, channel_name)
+            dcau = differential_caudality(array, channel_name)
+            return np.concatenate([psd,mad,skw,krt,de,rasm,dasm,dcau],axis=-1), feature_list
+        else:
+            return np.concatenate([psd,mad,skw,krt,de],axis=-1), feature_list
+
+
