@@ -11,27 +11,27 @@ import torch.nn.functional as F
 
 # 定义卷积网络结构
 class ConvNet(nn.Module):
-    def __init__(self, num_classes):
+    def __init__(self, in_channel=40, num_classes=1):
         super(ConvNet, self).__init__()
         self.layer1 = nn.Sequential(
-            nn.Conv2d(1, 32, kernel_size=5, stride=(1, 1), padding=(2, 2), bias=True),
-            nn.BatchNorm2d(32),
+            nn.Conv1d(in_channel, 32, kernel_size=5, stride=(1), padding=(2), bias=True),
+            nn.BatchNorm1d(32),
             nn.LeakyReLU(),
-            nn.AvgPool2d(kernel_size=2, stride=2)
+            nn.AvgPool1d(kernel_size=2, stride=2)
         )
         self.layer2 = nn.Sequential(
-            nn.Conv2d(32, 64, kernel_size=5, stride=(1, 1), padding=(2, 2), bias=True),
-            nn.BatchNorm2d(64),
+            nn.Conv1d(32, 64, kernel_size=5, stride=(1), padding=(2), bias=True),
+            nn.BatchNorm1d(64),
             nn.LeakyReLU(),
-            nn.AvgPool2d(kernel_size=2, stride=2)
+            nn.AvgPool1d(kernel_size=2, stride=2)
         )
         self.layer3 = nn.Sequential(
-            nn.Conv2d(64, 128, kernel_size=3, stride=(1, 1), padding=(1, 1), bias=True),
-            nn.BatchNorm2d(128),
+            nn.Conv1d(64, 128, kernel_size=3, stride=(1), padding=(1), bias=True),
+            nn.BatchNorm1d(128),
             nn.LeakyReLU(),
-            nn.AvgPool2d(kernel_size=2, stride=2)
+            nn.AvgPool1d(kernel_size=2, stride=2)
         )
-        self.fc1 = nn.Linear(128 * 7 * 25, 256, bias=True)
+        self.fc1 = nn.Linear(128 * 1008, 256, bias=True)
         self.fc2 = nn.Linear(256, num_classes, bias=True)
 
     def forward(self, x):
@@ -42,7 +42,6 @@ class ConvNet(nn.Module):
         out = self.fc1(out)
         out = self.fc2(out)
         return out
-
 #Example
 '''
 model = ConvNet(num_classes).to(device)
